# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidreversalsProcessingInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_solution': 'str',
        'reconciliation_id': 'str',
        'link_id': 'str',
        'report_group': 'str',
        'visa_checkout_id': 'str',
        'issuer': 'Ptsv2paymentsIssuerInformation'
    }

    attribute_map = {
        'payment_solution': 'paymentSolution',
        'reconciliation_id': 'reconciliationId',
        'link_id': 'linkId',
        'report_group': 'reportGroup',
        'visa_checkout_id': 'visaCheckoutId',
        'issuer': 'issuer'
    }

    def __init__(self, payment_solution=None, reconciliation_id=None, link_id=None, report_group=None, visa_checkout_id=None, issuer=None):
        """
        Ptsv2paymentsidreversalsProcessingInformation - a model defined in Swagger
        """

        self._payment_solution = None
        self._reconciliation_id = None
        self._link_id = None
        self._report_group = None
        self._visa_checkout_id = None
        self._issuer = None

        if payment_solution is not None:
          self.payment_solution = payment_solution
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if link_id is not None:
          self.link_id = link_id
        if report_group is not None:
          self.report_group = report_group
        if visa_checkout_id is not None:
          self.visa_checkout_id = visa_checkout_id
        if issuer is not None:
          self.issuer = issuer

    @property
    def payment_solution(self):
        """
        Gets the payment_solution of this Ptsv2paymentsidreversalsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :return: The payment_solution of this Ptsv2paymentsidreversalsProcessingInformation.
        :rtype: str
        """
        return self._payment_solution

    @payment_solution.setter
    def payment_solution(self, payment_solution):
        """
        Sets the payment_solution of this Ptsv2paymentsidreversalsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :param payment_solution: The payment_solution of this Ptsv2paymentsidreversalsProcessingInformation.
        :type: str
        """
        if payment_solution is not None and len(payment_solution) > 12:
            raise ValueError("Invalid value for `payment_solution`, length must be less than or equal to `12`")

        self._payment_solution = payment_solution

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this Ptsv2paymentsidreversalsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :return: The reconciliation_id of this Ptsv2paymentsidreversalsProcessingInformation.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this Ptsv2paymentsidreversalsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :param reconciliation_id: The reconciliation_id of this Ptsv2paymentsidreversalsProcessingInformation.
        :type: str
        """
        if reconciliation_id is not None and len(reconciliation_id) > 60:
            raise ValueError("Invalid value for `reconciliation_id`, length must be less than or equal to `60`")

        self._reconciliation_id = reconciliation_id

    @property
    def link_id(self):
        """
        Gets the link_id of this Ptsv2paymentsidreversalsProcessingInformation.
        Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request.  This value is used for:  - Partial authorizations - Split shipments  For details, see `link_to_request` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The link_id of this Ptsv2paymentsidreversalsProcessingInformation.
        :rtype: str
        """
        return self._link_id

    @link_id.setter
    def link_id(self, link_id):
        """
        Sets the link_id of this Ptsv2paymentsidreversalsProcessingInformation.
        Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request.  This value is used for:  - Partial authorizations - Split shipments  For details, see `link_to_request` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param link_id: The link_id of this Ptsv2paymentsidreversalsProcessingInformation.
        :type: str
        """
        if link_id is not None and len(link_id) > 26:
            raise ValueError("Invalid value for `link_id`, length must be less than or equal to `26`")

        self._link_id = link_id

    @property
    def report_group(self):
        """
        Gets the report_group of this Ptsv2paymentsidreversalsProcessingInformation.
        Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.  For details, see `report_group` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The report_group of this Ptsv2paymentsidreversalsProcessingInformation.
        :rtype: str
        """
        return self._report_group

    @report_group.setter
    def report_group(self, report_group):
        """
        Sets the report_group of this Ptsv2paymentsidreversalsProcessingInformation.
        Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.  For details, see `report_group` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param report_group: The report_group of this Ptsv2paymentsidreversalsProcessingInformation.
        :type: str
        """
        if report_group is not None and len(report_group) > 25:
            raise ValueError("Invalid value for `report_group`, length must be less than or equal to `25`")

        self._report_group = report_group

    @property
    def visa_checkout_id(self):
        """
        Gets the visa_checkout_id of this Ptsv2paymentsidreversalsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :return: The visa_checkout_id of this Ptsv2paymentsidreversalsProcessingInformation.
        :rtype: str
        """
        return self._visa_checkout_id

    @visa_checkout_id.setter
    def visa_checkout_id(self, visa_checkout_id):
        """
        Sets the visa_checkout_id of this Ptsv2paymentsidreversalsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :param visa_checkout_id: The visa_checkout_id of this Ptsv2paymentsidreversalsProcessingInformation.
        :type: str
        """
        if visa_checkout_id is not None and len(visa_checkout_id) > 48:
            raise ValueError("Invalid value for `visa_checkout_id`, length must be less than or equal to `48`")

        self._visa_checkout_id = visa_checkout_id

    @property
    def issuer(self):
        """
        Gets the issuer of this Ptsv2paymentsidreversalsProcessingInformation.

        :return: The issuer of this Ptsv2paymentsidreversalsProcessingInformation.
        :rtype: Ptsv2paymentsIssuerInformation
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """
        Sets the issuer of this Ptsv2paymentsidreversalsProcessingInformation.

        :param issuer: The issuer of this Ptsv2paymentsidreversalsProcessingInformation.
        :type: Ptsv2paymentsIssuerInformation
        """

        self._issuer = issuer

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidreversalsProcessingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class PayerAuthenticationApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
	
    def __init__(self, merchant_config, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client
        self.api_client.set_configuration(merchant_config) 


    def check_payer_auth_enrollment(self, check_payer_auth_enrollment_request, **kwargs):
        """
        Check Payer Auth Enrollment
        This call verifies that the card is enrolled in a card authentication program.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.check_payer_auth_enrollment(check_payer_auth_enrollment_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CheckPayerAuthEnrollmentRequest check_payer_auth_enrollment_request: (required)
        :return: RiskV1AuthenticationsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.check_payer_auth_enrollment_with_http_info(check_payer_auth_enrollment_request, **kwargs)
        else:
            (data) = self.check_payer_auth_enrollment_with_http_info(check_payer_auth_enrollment_request, **kwargs)
            return data

    def check_payer_auth_enrollment_with_http_info(self, check_payer_auth_enrollment_request, **kwargs):
        """
        Check Payer Auth Enrollment
        This call verifies that the card is enrolled in a card authentication program.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.check_payer_auth_enrollment_with_http_info(check_payer_auth_enrollment_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CheckPayerAuthEnrollmentRequest check_payer_auth_enrollment_request: (required)
        :return: RiskV1AuthenticationsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['check_payer_auth_enrollment_request']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check_payer_auth_enrollment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'check_payer_auth_enrollment_request' is set
        if ('check_payer_auth_enrollment_request' not in params) or (params['check_payer_auth_enrollment_request'] is None):
            raise ValueError("Missing the required parameter `check_payer_auth_enrollment_request` when calling `check_payer_auth_enrollment`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'check_payer_auth_enrollment_request' in params:
            body_params = params['check_payer_auth_enrollment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/risk/v1/authentications', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RiskV1AuthenticationsPost201Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def payer_auth_setup(self, payer_auth_setup_request, **kwargs):
        """
        Setup Payer Auth
        A new service for Merchants to get reference_id for Digital Wallets to use in place of BIN number in Cardinal. Set up file while authenticating with Cardinal. This service should be called by Merchant when payment instrument chosen or changes. This service has to be called before enrollment check.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.payer_auth_setup(payer_auth_setup_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param PayerAuthSetupRequest payer_auth_setup_request: (required)
        :return: RiskV1AuthenticationSetupsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.payer_auth_setup_with_http_info(payer_auth_setup_request, **kwargs)
        else:
            (data) = self.payer_auth_setup_with_http_info(payer_auth_setup_request, **kwargs)
            return data

    def payer_auth_setup_with_http_info(self, payer_auth_setup_request, **kwargs):
        """
        Setup Payer Auth
        A new service for Merchants to get reference_id for Digital Wallets to use in place of BIN number in Cardinal. Set up file while authenticating with Cardinal. This service should be called by Merchant when payment instrument chosen or changes. This service has to be called before enrollment check.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.payer_auth_setup_with_http_info(payer_auth_setup_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param PayerAuthSetupRequest payer_auth_setup_request: (required)
        :return: RiskV1AuthenticationSetupsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payer_auth_setup_request']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payer_auth_setup" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payer_auth_setup_request' is set
        if ('payer_auth_setup_request' not in params) or (params['payer_auth_setup_request'] is None):
            raise ValueError("Missing the required parameter `payer_auth_setup_request` when calling `payer_auth_setup`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payer_auth_setup_request' in params:
            body_params = params['payer_auth_setup_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/risk/v1/authentication-setups', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RiskV1AuthenticationSetupsPost201Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def validate_authentication_results(self, validate_request, **kwargs):
        """
        Validate Authentication Results
        This call retrieves and validates the authentication results from issuer and allows the merchant to proceed with processing the payment. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_authentication_results(validate_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ValidateRequest validate_request: (required)
        :return: RiskV1AuthenticationResultsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.validate_authentication_results_with_http_info(validate_request, **kwargs)
        else:
            (data) = self.validate_authentication_results_with_http_info(validate_request, **kwargs)
            return data

    def validate_authentication_results_with_http_info(self, validate_request, **kwargs):
        """
        Validate Authentication Results
        This call retrieves and validates the authentication results from issuer and allows the merchant to proceed with processing the payment. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_authentication_results_with_http_info(validate_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ValidateRequest validate_request: (required)
        :return: RiskV1AuthenticationResultsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['validate_request']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_authentication_results" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'validate_request' is set
        if ('validate_request' not in params) or (params['validate_request'] is None):
            raise ValueError("Missing the required parameter `validate_request` when calling `validate_authentication_results`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'validate_request' in params:
            body_params = params['validate_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/risk/v1/authentication-results', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RiskV1AuthenticationResultsPost201Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_type': 'str',
        'account_status': 'str',
        'balances': 'list[PtsV2PaymentsPost201ResponsePaymentInformationAccountFeaturesBalances]',
        'balance_amount': 'str',
        'balance_amount_type': 'str',
        'currency': 'str',
        'balance_sign': 'str',
        'affluence_indicator': 'str',
        'category': 'str',
        'commercial': 'str',
        'group': 'str',
        'health_care': 'str',
        'payroll': 'str',
        'level3_eligible': 'str',
        'pinless_debit': 'str',
        'signature_debit': 'str',
        'prepaid': 'str',
        'regulated': 'str'
    }

    attribute_map = {
        'account_type': 'accountType',
        'account_status': 'accountStatus',
        'balances': 'balances',
        'balance_amount': 'balanceAmount',
        'balance_amount_type': 'balanceAmountType',
        'currency': 'currency',
        'balance_sign': 'balanceSign',
        'affluence_indicator': 'affluenceIndicator',
        'category': 'category',
        'commercial': 'commercial',
        'group': 'group',
        'health_care': 'healthCare',
        'payroll': 'payroll',
        'level3_eligible': 'level3Eligible',
        'pinless_debit': 'pinlessDebit',
        'signature_debit': 'signatureDebit',
        'prepaid': 'prepaid',
        'regulated': 'regulated'
    }

    def __init__(self, account_type=None, account_status=None, balances=None, balance_amount=None, balance_amount_type=None, currency=None, balance_sign=None, affluence_indicator=None, category=None, commercial=None, group=None, health_care=None, payroll=None, level3_eligible=None, pinless_debit=None, signature_debit=None, prepaid=None, regulated=None):
        """
        PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures - a model defined in Swagger
        """

        self._account_type = None
        self._account_status = None
        self._balances = None
        self._balance_amount = None
        self._balance_amount_type = None
        self._currency = None
        self._balance_sign = None
        self._affluence_indicator = None
        self._category = None
        self._commercial = None
        self._group = None
        self._health_care = None
        self._payroll = None
        self._level3_eligible = None
        self._pinless_debit = None
        self._signature_debit = None
        self._prepaid = None
        self._regulated = None

        if account_type is not None:
          self.account_type = account_type
        if account_status is not None:
          self.account_status = account_status
        if balances is not None:
          self.balances = balances
        if balance_amount is not None:
          self.balance_amount = balance_amount
        if balance_amount_type is not None:
          self.balance_amount_type = balance_amount_type
        if currency is not None:
          self.currency = currency
        if balance_sign is not None:
          self.balance_sign = balance_sign
        if affluence_indicator is not None:
          self.affluence_indicator = affluence_indicator
        if category is not None:
          self.category = category
        if commercial is not None:
          self.commercial = commercial
        if group is not None:
          self.group = group
        if health_care is not None:
          self.health_care = health_care
        if payroll is not None:
          self.payroll = payroll
        if level3_eligible is not None:
          self.level3_eligible = level3_eligible
        if pinless_debit is not None:
          self.pinless_debit = pinless_debit
        if signature_debit is not None:
          self.signature_debit = signature_debit
        if prepaid is not None:
          self.prepaid = prepaid
        if regulated is not None:
          self.regulated = regulated

    @property
    def account_type(self):
        """
        Gets the account_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Type of account. This value is returned only if you requested a balance inquiry. Possible values:   - `00`: Not applicable or not specified  - `10`: Savings account  - `20`: Checking account  - `30`: Credit card account  - `40`: Universal account  #### PIN debit Type of account. This value is returned only if you requested a balance inquiry.  Possible values: - `00`: Not applicable or not specified - `10`: Savings account - `20`: Checking account - `40`: Universal account - `96`: Cash benefits account - `98`: Food stamp account  Returned by PIN debit purchase. 

        :return: The account_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._account_type

    @account_type.setter
    def account_type(self, account_type):
        """
        Sets the account_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Type of account. This value is returned only if you requested a balance inquiry. Possible values:   - `00`: Not applicable or not specified  - `10`: Savings account  - `20`: Checking account  - `30`: Credit card account  - `40`: Universal account  #### PIN debit Type of account. This value is returned only if you requested a balance inquiry.  Possible values: - `00`: Not applicable or not specified - `10`: Savings account - `20`: Checking account - `40`: Universal account - `96`: Cash benefits account - `98`: Food stamp account  Returned by PIN debit purchase. 

        :param account_type: The account_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if account_type is not None and len(account_type) > 2:
            raise ValueError("Invalid value for `account_type`, length must be less than or equal to `2`")

        self._account_type = account_type

    @property
    def account_status(self):
        """
        Gets the account_status of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Possible values: - `N`: Nonregulated - `R`: Regulated  Returned by PIN debit credit or PIN debit purchase.  **Note** This field is returned only for CyberSource through VisaNet. 

        :return: The account_status of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._account_status

    @account_status.setter
    def account_status(self, account_status):
        """
        Sets the account_status of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Possible values: - `N`: Nonregulated - `R`: Regulated  Returned by PIN debit credit or PIN debit purchase.  **Note** This field is returned only for CyberSource through VisaNet. 

        :param account_status: The account_status of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if account_status is not None and len(account_status) > 1:
            raise ValueError("Invalid value for `account_status`, length must be less than or equal to `1`")

        self._account_status = account_status

    @property
    def balances(self):
        """
        Gets the balances of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        This is an array of multiple balances information an issuer can return for a given card.

        :return: The balances of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: list[PtsV2PaymentsPost201ResponsePaymentInformationAccountFeaturesBalances]
        """
        return self._balances

    @balances.setter
    def balances(self, balances):
        """
        Sets the balances of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        This is an array of multiple balances information an issuer can return for a given card.

        :param balances: The balances of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: list[PtsV2PaymentsPost201ResponsePaymentInformationAccountFeaturesBalances]
        """

        self._balances = balances

    @property
    def balance_amount(self):
        """
        Gets the balance_amount of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :return: The balance_amount of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._balance_amount

    @balance_amount.setter
    def balance_amount(self, balance_amount):
        """
        Sets the balance_amount of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :param balance_amount: The balance_amount of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if balance_amount is not None and len(balance_amount) > 12:
            raise ValueError("Invalid value for `balance_amount`, length must be less than or equal to `12`")

        self._balance_amount = balance_amount

    @property
    def balance_amount_type(self):
        """
        Gets the balance_amount_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Type of amount. This value is returned only if you requested a balance inquiry. The issuer determines the value that is returned. Possible values for deposit accounts:   - `01`: Current ledger (posted) balance.  - `02`: Current available balance, which is typically the ledger balance less outstanding authorizations.  Some depository institutions also include pending deposits and the credit or overdraft line associated with the account. Possible values for credit card accounts:   - `01`: Credit amount remaining for customer (open to buy).  - `02`: Credit limit. 

        :return: The balance_amount_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._balance_amount_type

    @balance_amount_type.setter
    def balance_amount_type(self, balance_amount_type):
        """
        Sets the balance_amount_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Type of amount. This value is returned only if you requested a balance inquiry. The issuer determines the value that is returned. Possible values for deposit accounts:   - `01`: Current ledger (posted) balance.  - `02`: Current available balance, which is typically the ledger balance less outstanding authorizations.  Some depository institutions also include pending deposits and the credit or overdraft line associated with the account. Possible values for credit card accounts:   - `01`: Credit amount remaining for customer (open to buy).  - `02`: Credit limit. 

        :param balance_amount_type: The balance_amount_type of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if balance_amount_type is not None and len(balance_amount_type) > 2:
            raise ValueError("Invalid value for `balance_amount_type`, length must be less than or equal to `2`")

        self._balance_amount_type = balance_amount_type

    @property
    def currency(self):
        """
        Gets the currency of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Currency of the remaining balance on the account. For the possible values, see the [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  Returned by authorization service.  #### PIN debit Currency of the remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :return: The currency of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Currency of the remaining balance on the account. For the possible values, see the [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  Returned by authorization service.  #### PIN debit Currency of the remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :param currency: The currency of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if currency is not None and len(currency) > 5:
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `5`")

        self._currency = currency

    @property
    def balance_sign(self):
        """
        Gets the balance_sign of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Sign for the remaining balance on the account. Returned only when the processor returns this value. Possible values:  Possible values: - `Positive` - `Negative`  #### PIN debit Sign for the remaining balance on the prepaid card. Returned only when the processor returns this value.  Returned by PIN debit purchase. 

        :return: The balance_sign of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._balance_sign

    @balance_sign.setter
    def balance_sign(self, balance_sign):
        """
        Sets the balance_sign of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Sign for the remaining balance on the account. Returned only when the processor returns this value. Possible values:  Possible values: - `Positive` - `Negative`  #### PIN debit Sign for the remaining balance on the prepaid card. Returned only when the processor returns this value.  Returned by PIN debit purchase. 

        :param balance_sign: The balance_sign of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if balance_sign is not None and len(balance_sign) > 8:
            raise ValueError("Invalid value for `balance_sign`, length must be less than or equal to `8`")

        self._balance_sign = balance_sign

    @property
    def affluence_indicator(self):
        """
        Gets the affluence_indicator of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        **Chase Paymentech Solutions**  Indicates whether a customer has high credit limits. This information enables you to market high cost items to these customers and to understand the kinds of cards that high income customers are using.  This field is supported for Visa, Mastercard, Discover, and Diners Club. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown  #### Litle  Flag that indicates that a Visa cardholder or Mastercard cardholder is in one of the affluent categories. Possible values:   - `AFFLUENT`: High income customer with high spending pattern (>100k USD annual income and >40k USD annual    card usage).  - `MASS AFFLUENT`: High income customer (>100k USD annual income).   Maximum length is 13.  #### Chase Paymentech Solutions  Maximum length is 1. 

        :return: The affluence_indicator of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._affluence_indicator

    @affluence_indicator.setter
    def affluence_indicator(self, affluence_indicator):
        """
        Sets the affluence_indicator of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        **Chase Paymentech Solutions**  Indicates whether a customer has high credit limits. This information enables you to market high cost items to these customers and to understand the kinds of cards that high income customers are using.  This field is supported for Visa, Mastercard, Discover, and Diners Club. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown  #### Litle  Flag that indicates that a Visa cardholder or Mastercard cardholder is in one of the affluent categories. Possible values:   - `AFFLUENT`: High income customer with high spending pattern (>100k USD annual income and >40k USD annual    card usage).  - `MASS AFFLUENT`: High income customer (>100k USD annual income).   Maximum length is 13.  #### Chase Paymentech Solutions  Maximum length is 1. 

        :param affluence_indicator: The affluence_indicator of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if affluence_indicator is not None and len(affluence_indicator) > 13:
            raise ValueError("Invalid value for `affluence_indicator`, length must be less than or equal to `13`")

        self._affluence_indicator = affluence_indicator

    @property
    def category(self):
        """
        Gets the category of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        #### GPX Mastercard product ID associated with the primary account number (PAN). Returned by authorization service.  #### CyberSource through VisaNet Visa or Mastercard product ID that is associated with the primary account number (PAN). For descriptions of the Visa product IDs, see the Product ID table on the [Visa Request & Response Codes web page.](https://developer.visa.com/guides/request_response_codes)  Data Length: String (3)  #### GPN Visa or Mastercard product ID that is associated with the primary account number (PAN). For descriptions of the Visa product IDs, see the Product ID table on the [Visa Request & Response Codes web page.](https://developer.visa.com/guides/request_response_codes)  Data Length: String (3)  #### Worldpay VAP **Important** Before using this field on Worldpay VAP, you must contact CyberSource Customer Support to have your account configured for this feature.  Type of card used in the transaction. The only possible value is: - `PREPAID`: Prepaid Card  Data Length: String (7)  #### RBS WorldPay Atlanta Type of card used in the transaction. Possible values: - `B`: Business Card - `O`: Noncommercial Card - `R`: Corporate Card - `S`: Purchase Card - `Blank`: Purchase card not supported  Data Length: String (1) 

        :return: The category of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        #### GPX Mastercard product ID associated with the primary account number (PAN). Returned by authorization service.  #### CyberSource through VisaNet Visa or Mastercard product ID that is associated with the primary account number (PAN). For descriptions of the Visa product IDs, see the Product ID table on the [Visa Request & Response Codes web page.](https://developer.visa.com/guides/request_response_codes)  Data Length: String (3)  #### GPN Visa or Mastercard product ID that is associated with the primary account number (PAN). For descriptions of the Visa product IDs, see the Product ID table on the [Visa Request & Response Codes web page.](https://developer.visa.com/guides/request_response_codes)  Data Length: String (3)  #### Worldpay VAP **Important** Before using this field on Worldpay VAP, you must contact CyberSource Customer Support to have your account configured for this feature.  Type of card used in the transaction. The only possible value is: - `PREPAID`: Prepaid Card  Data Length: String (7)  #### RBS WorldPay Atlanta Type of card used in the transaction. Possible values: - `B`: Business Card - `O`: Noncommercial Card - `R`: Corporate Card - `S`: Purchase Card - `Blank`: Purchase card not supported  Data Length: String (1) 

        :param category: The category of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if category is not None and len(category) > 7:
            raise ValueError("Invalid value for `category`, length must be less than or equal to `7`")

        self._category = category

    @property
    def commercial(self):
        """
        Gets the commercial of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a commercial card, which enables you to include Level II data in your transaction requests. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The commercial of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._commercial

    @commercial.setter
    def commercial(self, commercial):
        """
        Sets the commercial of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a commercial card, which enables you to include Level II data in your transaction requests. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param commercial: The commercial of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if commercial is not None and len(commercial) > 1:
            raise ValueError("Invalid value for `commercial`, length must be less than or equal to `1`")

        self._commercial = commercial

    @property
    def group(self):
        """
        Gets the group of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Type of commercial card. This field is supported only for CyberSource through VisaNet. Possible values:   - `B`: Business card  - `R`: Corporate card  - `S`: Purchasing card  - `0`: Noncommercial card  Returned by authorization service. 

        :return: The group of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Type of commercial card. This field is supported only for CyberSource through VisaNet. Possible values:   - `B`: Business card  - `R`: Corporate card  - `S`: Purchasing card  - `0`: Noncommercial card  Returned by authorization service. 

        :param group: The group of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if group is not None and len(group) > 1:
            raise ValueError("Invalid value for `group`, length must be less than or equal to `1`")

        self._group = group

    @property
    def health_care(self):
        """
        Gets the health_care of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a healthcare card. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The health_care of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._health_care

    @health_care.setter
    def health_care(self, health_care):
        """
        Sets the health_care of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a healthcare card. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param health_care: The health_care of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if health_care is not None and len(health_care) > 1:
            raise ValueError("Invalid value for `health_care`, length must be less than or equal to `1`")

        self._health_care = health_care

    @property
    def payroll(self):
        """
        Gets the payroll of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a payroll card. This field is supported for Visa, Discover, Diners Club, and JCB on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The payroll of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._payroll

    @payroll.setter
    def payroll(self, payroll):
        """
        Sets the payroll of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a payroll card. This field is supported for Visa, Discover, Diners Club, and JCB on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param payroll: The payroll of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if payroll is not None and len(payroll) > 1:
            raise ValueError("Invalid value for `payroll`, length must be less than or equal to `1`")

        self._payroll = payroll

    @property
    def level3_eligible(self):
        """
        Gets the level3_eligible of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is eligible for Level III interchange fees, which enables you to include Level III data in your transaction requests. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The level3_eligible of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._level3_eligible

    @level3_eligible.setter
    def level3_eligible(self, level3_eligible):
        """
        Sets the level3_eligible of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is eligible for Level III interchange fees, which enables you to include Level III data in your transaction requests. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param level3_eligible: The level3_eligible of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if level3_eligible is not None and len(level3_eligible) > 1:
            raise ValueError("Invalid value for `level3_eligible`, length must be less than or equal to `1`")

        self._level3_eligible = level3_eligible

    @property
    def pinless_debit(self):
        """
        Gets the pinless_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a PINless debit card. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The pinless_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._pinless_debit

    @pinless_debit.setter
    def pinless_debit(self, pinless_debit):
        """
        Sets the pinless_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a PINless debit card. This field is supported for Visa and Mastercard on **Chase Paymentech Solutions**. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param pinless_debit: The pinless_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if pinless_debit is not None and len(pinless_debit) > 1:
            raise ValueError("Invalid value for `pinless_debit`, length must be less than or equal to `1`")

        self._pinless_debit = pinless_debit

    @property
    def signature_debit(self):
        """
        Gets the signature_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a signature debit card.  This information enables you to alter the way an order is processed. For example, you might not want to reauthorize a transaction for a signature debit card, or you might want to perform reversals promptly for a signature debit card. This field is supported for Visa, Mastercard, and Maestro (International) on Chase Paymentech Solutions. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The signature_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._signature_debit

    @signature_debit.setter
    def signature_debit(self, signature_debit):
        """
        Sets the signature_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a signature debit card.  This information enables you to alter the way an order is processed. For example, you might not want to reauthorize a transaction for a signature debit card, or you might want to perform reversals promptly for a signature debit card. This field is supported for Visa, Mastercard, and Maestro (International) on Chase Paymentech Solutions. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param signature_debit: The signature_debit of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if signature_debit is not None and len(signature_debit) > 1:
            raise ValueError("Invalid value for `signature_debit`, length must be less than or equal to `1`")

        self._signature_debit = signature_debit

    @property
    def prepaid(self):
        """
        Gets the prepaid of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a prepaid card. This information enables you to determine when a gift card or prepaid card is presented for use when establishing a new recurring, installment, or deferred billing relationship.  This field is supported for Visa, Mastercard, Discover, Diners Club, and JCB on Chase Paymentech Solutions. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The prepaid of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._prepaid

    @prepaid.setter
    def prepaid(self, prepaid):
        """
        Sets the prepaid of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is a prepaid card. This information enables you to determine when a gift card or prepaid card is presented for use when establishing a new recurring, installment, or deferred billing relationship.  This field is supported for Visa, Mastercard, Discover, Diners Club, and JCB on Chase Paymentech Solutions. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param prepaid: The prepaid of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if prepaid is not None and len(prepaid) > 1:
            raise ValueError("Invalid value for `prepaid`, length must be less than or equal to `1`")

        self._prepaid = prepaid

    @property
    def regulated(self):
        """
        Gets the regulated of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is regulated according to the Durbin Amendment. If the card is regulated, the card issuer is subject to price caps and interchange rules. This field is supported for Visa, Mastercard, Discover, Diners Club, and JCB on Chase Paymentech Solutions. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :return: The regulated of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._regulated

    @regulated.setter
    def regulated(self, regulated):
        """
        Sets the regulated of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        Indicates whether the card is regulated according to the Durbin Amendment. If the card is regulated, the card issuer is subject to price caps and interchange rules. This field is supported for Visa, Mastercard, Discover, Diners Club, and JCB on Chase Paymentech Solutions. Possible values:   - `Y`: Yes  - `N`: No  - `X`: Not applicable / Unknown 

        :param regulated: The regulated of this PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if regulated is not None and len(regulated) > 1:
            raise ValueError("Invalid value for `regulated`, length must be less than or equal to `1`")

        self._regulated = regulated

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Vasv2taxOrderInformationLineItems(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'product_sku': 'str',
        'product_code': 'str',
        'quantity': 'int',
        'product_name': 'str',
        'unit_price': 'str',
        'tax_amount': 'str',
        'order_acceptance': 'Vasv2taxOrderInformationOrderAcceptance',
        'order_origin': 'Vasv2taxOrderInformationOrderOrigin',
        'ship_from_country': 'str',
        'ship_from_administrative_area': 'str',
        'ship_from_locality': 'str',
        'ship_from_postal_code': 'str',
        'buyer_vat_registration_number': 'str',
        'seller_vat_registration_number': 'str'
    }

    attribute_map = {
        'product_sku': 'productSKU',
        'product_code': 'productCode',
        'quantity': 'quantity',
        'product_name': 'productName',
        'unit_price': 'unitPrice',
        'tax_amount': 'taxAmount',
        'order_acceptance': 'orderAcceptance',
        'order_origin': 'orderOrigin',
        'ship_from_country': 'shipFromCountry',
        'ship_from_administrative_area': 'shipFromAdministrativeArea',
        'ship_from_locality': 'shipFromLocality',
        'ship_from_postal_code': 'shipFromPostalCode',
        'buyer_vat_registration_number': 'buyerVatRegistrationNumber',
        'seller_vat_registration_number': 'sellerVatRegistrationNumber'
    }

    def __init__(self, product_sku=None, product_code=None, quantity=None, product_name=None, unit_price=None, tax_amount=None, order_acceptance=None, order_origin=None, ship_from_country=None, ship_from_administrative_area=None, ship_from_locality=None, ship_from_postal_code=None, buyer_vat_registration_number=None, seller_vat_registration_number=None):
        """
        Vasv2taxOrderInformationLineItems - a model defined in Swagger
        """

        self._product_sku = None
        self._product_code = None
        self._quantity = None
        self._product_name = None
        self._unit_price = None
        self._tax_amount = None
        self._order_acceptance = None
        self._order_origin = None
        self._ship_from_country = None
        self._ship_from_administrative_area = None
        self._ship_from_locality = None
        self._ship_from_postal_code = None
        self._buyer_vat_registration_number = None
        self._seller_vat_registration_number = None

        if product_sku is not None:
          self.product_sku = product_sku
        if product_code is not None:
          self.product_code = product_code
        if quantity is not None:
          self.quantity = quantity
        if product_name is not None:
          self.product_name = product_name
        if unit_price is not None:
          self.unit_price = unit_price
        if tax_amount is not None:
          self.tax_amount = tax_amount
        if order_acceptance is not None:
          self.order_acceptance = order_acceptance
        if order_origin is not None:
          self.order_origin = order_origin
        if ship_from_country is not None:
          self.ship_from_country = ship_from_country
        if ship_from_administrative_area is not None:
          self.ship_from_administrative_area = ship_from_administrative_area
        if ship_from_locality is not None:
          self.ship_from_locality = ship_from_locality
        if ship_from_postal_code is not None:
          self.ship_from_postal_code = ship_from_postal_code
        if buyer_vat_registration_number is not None:
          self.buyer_vat_registration_number = buyer_vat_registration_number
        if seller_vat_registration_number is not None:
          self.seller_vat_registration_number = seller_vat_registration_number

    @property
    def product_sku(self):
        """
        Gets the product_sku of this Vasv2taxOrderInformationLineItems.
        Product identifier code. Also known as the Stock Keeping Unit (SKU) code for the product.  For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not set to **default** or one of the other values that are related to shipping and/or handling.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the values related to shipping and/or handling. 

        :return: The product_sku of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._product_sku

    @product_sku.setter
    def product_sku(self, product_sku):
        """
        Sets the product_sku of this Vasv2taxOrderInformationLineItems.
        Product identifier code. Also known as the Stock Keeping Unit (SKU) code for the product.  For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not set to **default** or one of the other values that are related to shipping and/or handling.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the values related to shipping and/or handling. 

        :param product_sku: The product_sku of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if product_sku is not None and len(product_sku) > 255:
            raise ValueError("Invalid value for `product_sku`, length must be less than or equal to `255`")

        self._product_sku = product_sku

    @property
    def product_code(self):
        """
        Gets the product_code of this Vasv2taxOrderInformationLineItems.
        Type of product. The value for this field is used to identify the product category (electronic, handling, physical, service, or shipping). The default value is `default`.  If you are performing an authorization transaction (`processingOptions.capture` is set to `false`), and you set this field to a value other than `default` or one of the values related to shipping and/or handling, then `orderInformation.lineItems[].quantity`, `orderInformation.lineItems[].productName`, and `orderInformation.lineItems[].productSku` fields are required.  Optional field.  For details, see the `product_code` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/).  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes.  To use the tax calculation service, use values listed in the Tax Product Code Guide. For information about this document, contact customer support. See \"Product Codes,\" page 14, for more information. 

        :return: The product_code of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._product_code

    @product_code.setter
    def product_code(self, product_code):
        """
        Sets the product_code of this Vasv2taxOrderInformationLineItems.
        Type of product. The value for this field is used to identify the product category (electronic, handling, physical, service, or shipping). The default value is `default`.  If you are performing an authorization transaction (`processingOptions.capture` is set to `false`), and you set this field to a value other than `default` or one of the values related to shipping and/or handling, then `orderInformation.lineItems[].quantity`, `orderInformation.lineItems[].productName`, and `orderInformation.lineItems[].productSku` fields are required.  Optional field.  For details, see the `product_code` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/).  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes.  To use the tax calculation service, use values listed in the Tax Product Code Guide. For information about this document, contact customer support. See \"Product Codes,\" page 14, for more information. 

        :param product_code: The product_code of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if product_code is not None and len(product_code) > 255:
            raise ValueError("Invalid value for `product_code`, length must be less than or equal to `255`")

        self._product_code = product_code

    @property
    def quantity(self):
        """
        Gets the quantity of this Vasv2taxOrderInformationLineItems.
        Number of units for this order. Must be a non-negative integer.  The default is `1`. For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values related to shipping and/or handling.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. 

        :return: The quantity of this Vasv2taxOrderInformationLineItems.
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this Vasv2taxOrderInformationLineItems.
        Number of units for this order. Must be a non-negative integer.  The default is `1`. For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values related to shipping and/or handling.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. 

        :param quantity: The quantity of this Vasv2taxOrderInformationLineItems.
        :type: int
        """
        if quantity is not None and quantity > 999999999:
            raise ValueError("Invalid value for `quantity`, must be a value less than or equal to `999999999`")
        if quantity is not None and quantity < 1:
            raise ValueError("Invalid value for `quantity`, must be a value greater than or equal to `1`")

        self._quantity = quantity

    @property
    def product_name(self):
        """
        Gets the product_name of this Vasv2taxOrderInformationLineItems.
        For an authorization or capture transaction (`processingOptions.capture` is `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values that are related to shipping and/or handling.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. 

        :return: The product_name of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """
        Sets the product_name of this Vasv2taxOrderInformationLineItems.
        For an authorization or capture transaction (`processingOptions.capture` is `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values that are related to shipping and/or handling.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. 

        :param product_name: The product_name of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if product_name is not None and len(product_name) > 255:
            raise ValueError("Invalid value for `product_name`, length must be less than or equal to `255`")

        self._product_name = product_name

    @property
    def unit_price(self):
        """
        Gets the unit_price of this Vasv2taxOrderInformationLineItems.
        Per-item price of the product. This value for this field cannot be negative.  You must include either this field or the request-level field `orderInformation.amountDetails.totalAmount` in your request.  You can include a decimal point (.), but you cannot include any other special characters. The value is truncated to the correct number of decimal places.  #### DCC with a Third-Party Provider Set this field to the converted amount that was returned by the DCC provider. You must include either the 1st line item in the order and this field, or the request-level field `orderInformation.amountDetails.totalAmount` in your request.  #### FDMS South If you accept IDR or CLP currencies, see the entry for FDMS South in the [Merchant Descriptors Using the SCMP API Guide.] (https://apps.cybersource.com/library/documentation/dev_guides/Merchant_Descriptors_SCMP_API/html/)  #### Tax Calculation Required field for U.S., Canadian, international and value added taxes.  #### Zero Amount Authorizations If your processor supports zero amount authorizations, you can set this field to 0 for the authorization to check if the card is lost or stolen.  #### Maximum Field Lengths For GPN and JCN Gateway: Decimal (10) All other processors: Decimal (15) 

        :return: The unit_price of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._unit_price

    @unit_price.setter
    def unit_price(self, unit_price):
        """
        Sets the unit_price of this Vasv2taxOrderInformationLineItems.
        Per-item price of the product. This value for this field cannot be negative.  You must include either this field or the request-level field `orderInformation.amountDetails.totalAmount` in your request.  You can include a decimal point (.), but you cannot include any other special characters. The value is truncated to the correct number of decimal places.  #### DCC with a Third-Party Provider Set this field to the converted amount that was returned by the DCC provider. You must include either the 1st line item in the order and this field, or the request-level field `orderInformation.amountDetails.totalAmount` in your request.  #### FDMS South If you accept IDR or CLP currencies, see the entry for FDMS South in the [Merchant Descriptors Using the SCMP API Guide.] (https://apps.cybersource.com/library/documentation/dev_guides/Merchant_Descriptors_SCMP_API/html/)  #### Tax Calculation Required field for U.S., Canadian, international and value added taxes.  #### Zero Amount Authorizations If your processor supports zero amount authorizations, you can set this field to 0 for the authorization to check if the card is lost or stolen.  #### Maximum Field Lengths For GPN and JCN Gateway: Decimal (10) All other processors: Decimal (15) 

        :param unit_price: The unit_price of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if unit_price is not None and len(unit_price) > 15:
            raise ValueError("Invalid value for `unit_price`, length must be less than or equal to `15`")

        self._unit_price = unit_price

    @property
    def tax_amount(self):
        """
        Gets the tax_amount of this Vasv2taxOrderInformationLineItems.
        Total tax to apply to the product. This value cannot be negative. The tax amount and the offer amount must be in the same currency. The tax amount field is additive.  The following example uses a two-exponent currency such as USD:   1. You include each line item in your request.  ..- 1st line item has amount=10.00, quantity=1, and taxAmount=0.80  ..- 2nd line item has amount=20.00, quantity=1, and taxAmount=1.60  2. The total amount authorized will be 32.40, not 30.00 with 2.40 of tax included.  Optional field.  #### Airlines processing Tax portion of the order amount. This value cannot exceed 99999999999999 (fourteen 9s). Format: English characters only. Optional request field for a line item.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes.  Note if you send this field in your tax request, the value in the field will override the tax engine 

        :return: The tax_amount of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """
        Sets the tax_amount of this Vasv2taxOrderInformationLineItems.
        Total tax to apply to the product. This value cannot be negative. The tax amount and the offer amount must be in the same currency. The tax amount field is additive.  The following example uses a two-exponent currency such as USD:   1. You include each line item in your request.  ..- 1st line item has amount=10.00, quantity=1, and taxAmount=0.80  ..- 2nd line item has amount=20.00, quantity=1, and taxAmount=1.60  2. The total amount authorized will be 32.40, not 30.00 with 2.40 of tax included.  Optional field.  #### Airlines processing Tax portion of the order amount. This value cannot exceed 99999999999999 (fourteen 9s). Format: English characters only. Optional request field for a line item.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes.  Note if you send this field in your tax request, the value in the field will override the tax engine 

        :param tax_amount: The tax_amount of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if tax_amount is not None and len(tax_amount) > 15:
            raise ValueError("Invalid value for `tax_amount`, length must be less than or equal to `15`")

        self._tax_amount = tax_amount

    @property
    def order_acceptance(self):
        """
        Gets the order_acceptance of this Vasv2taxOrderInformationLineItems.

        :return: The order_acceptance of this Vasv2taxOrderInformationLineItems.
        :rtype: Vasv2taxOrderInformationOrderAcceptance
        """
        return self._order_acceptance

    @order_acceptance.setter
    def order_acceptance(self, order_acceptance):
        """
        Sets the order_acceptance of this Vasv2taxOrderInformationLineItems.

        :param order_acceptance: The order_acceptance of this Vasv2taxOrderInformationLineItems.
        :type: Vasv2taxOrderInformationOrderAcceptance
        """

        self._order_acceptance = order_acceptance

    @property
    def order_origin(self):
        """
        Gets the order_origin of this Vasv2taxOrderInformationLineItems.

        :return: The order_origin of this Vasv2taxOrderInformationLineItems.
        :rtype: Vasv2taxOrderInformationOrderOrigin
        """
        return self._order_origin

    @order_origin.setter
    def order_origin(self, order_origin):
        """
        Sets the order_origin of this Vasv2taxOrderInformationLineItems.

        :param order_origin: The order_origin of this Vasv2taxOrderInformationLineItems.
        :type: Vasv2taxOrderInformationOrderOrigin
        """

        self._order_origin = order_origin

    @property
    def ship_from_country(self):
        """
        Gets the ship_from_country of this Vasv2taxOrderInformationLineItems.
        Country from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromAdministrativeArea` are present. Use the [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/ or rates applied to the transaction based on sourcing.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The ship_from_country of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._ship_from_country

    @ship_from_country.setter
    def ship_from_country(self, ship_from_country):
        """
        Sets the ship_from_country of this Vasv2taxOrderInformationLineItems.
        Country from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromAdministrativeArea` are present. Use the [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/ or rates applied to the transaction based on sourcing.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param ship_from_country: The ship_from_country of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if ship_from_country is not None and len(ship_from_country) > 2:
            raise ValueError("Invalid value for `ship_from_country`, length must be less than or equal to `2`")

        self._ship_from_country = ship_from_country

    @property
    def ship_from_administrative_area(self):
        """
        Gets the ship_from_administrative_area of this Vasv2taxOrderInformationLineItems.
        State from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromCountry` are present. Use the [State, Province, and Territory Codes for the United States and Canada](http://apps.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :return: The ship_from_administrative_area of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._ship_from_administrative_area

    @ship_from_administrative_area.setter
    def ship_from_administrative_area(self, ship_from_administrative_area):
        """
        Sets the ship_from_administrative_area of this Vasv2taxOrderInformationLineItems.
        State from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromCountry` are present. Use the [State, Province, and Territory Codes for the United States and Canada](http://apps.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :param ship_from_administrative_area: The ship_from_administrative_area of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if ship_from_administrative_area is not None and len(ship_from_administrative_area) > 2:
            raise ValueError("Invalid value for `ship_from_administrative_area`, length must be less than or equal to `2`")

        self._ship_from_administrative_area = ship_from_administrative_area

    @property
    def ship_from_locality(self):
        """
        Gets the ship_from_locality of this Vasv2taxOrderInformationLineItems.
        City where the product is shipped from. This field is used only when the `orderInformation.shipTo.administrativeArea` and `orderInformation.shipTo.country` fields are present.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :return: The ship_from_locality of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._ship_from_locality

    @ship_from_locality.setter
    def ship_from_locality(self, ship_from_locality):
        """
        Sets the ship_from_locality of this Vasv2taxOrderInformationLineItems.
        City where the product is shipped from. This field is used only when the `orderInformation.shipTo.administrativeArea` and `orderInformation.shipTo.country` fields are present.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :param ship_from_locality: The ship_from_locality of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if ship_from_locality is not None and len(ship_from_locality) > 50:
            raise ValueError("Invalid value for `ship_from_locality`, length must be less than or equal to `50`")

        self._ship_from_locality = ship_from_locality

    @property
    def ship_from_postal_code(self):
        """
        Gets the ship_from_postal_code of this Vasv2taxOrderInformationLineItems.
        Postal code where the product is shipped from.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :return: The ship_from_postal_code of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._ship_from_postal_code

    @ship_from_postal_code.setter
    def ship_from_postal_code(self, ship_from_postal_code):
        """
        Sets the ship_from_postal_code of this Vasv2taxOrderInformationLineItems.
        Postal code where the product is shipped from.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :param ship_from_postal_code: The ship_from_postal_code of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if ship_from_postal_code is not None and len(ship_from_postal_code) > 10:
            raise ValueError("Invalid value for `ship_from_postal_code`, length must be less than or equal to `10`")

        self._ship_from_postal_code = ship_from_postal_code

    @property
    def buyer_vat_registration_number(self):
        """
        Gets the buyer_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        Buyer’s VAT registration number.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for international and value added taxes only. Not applicable to U.S. and Canadian taxes. 

        :return: The buyer_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._buyer_vat_registration_number

    @buyer_vat_registration_number.setter
    def buyer_vat_registration_number(self, buyer_vat_registration_number):
        """
        Sets the buyer_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        Buyer’s VAT registration number.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for international and value added taxes only. Not applicable to U.S. and Canadian taxes. 

        :param buyer_vat_registration_number: The buyer_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if buyer_vat_registration_number is not None and len(buyer_vat_registration_number) > 25:
            raise ValueError("Invalid value for `buyer_vat_registration_number`, length must be less than or equal to `25`")

        self._buyer_vat_registration_number = buyer_vat_registration_number

    @property
    def seller_vat_registration_number(self):
        """
        Gets the seller_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        VAT seller registration number.  For details, see \"International Taxes and Value-Added Tax (VAT)\" in [Tax Calculation Service Using the SCMP API](https://apps.cybersource.com/library/documentation/dev_guides/Tax_SCMP_API/html/).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for international and value added taxes only. Not applicable to U.S. and Canadian taxes. 

        :return: The seller_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        :rtype: str
        """
        return self._seller_vat_registration_number

    @seller_vat_registration_number.setter
    def seller_vat_registration_number(self, seller_vat_registration_number):
        """
        Sets the seller_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        VAT seller registration number.  For details, see \"International Taxes and Value-Added Tax (VAT)\" in [Tax Calculation Service Using the SCMP API](https://apps.cybersource.com/library/documentation/dev_guides/Tax_SCMP_API/html/).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for international and value added taxes only. Not applicable to U.S. and Canadian taxes. 

        :param seller_vat_registration_number: The seller_vat_registration_number of this Vasv2taxOrderInformationLineItems.
        :type: str
        """
        if seller_vat_registration_number is not None and len(seller_vat_registration_number) > 25:
            raise ValueError("Invalid value for `seller_vat_registration_number`, length must be less than or equal to `25`")

        self._seller_vat_registration_number = seller_vat_registration_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Vasv2taxOrderInformationLineItems):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class KeyParameters(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'encryption_type': 'str',
        'target_origin': 'str'
    }

    attribute_map = {
        'encryption_type': 'encryptionType',
        'target_origin': 'targetOrigin'
    }

    def __init__(self, encryption_type=None, target_origin=None):
        """
        KeyParameters - a model defined in Swagger
        """

        self._encryption_type = None
        self._target_origin = None

        self.encryption_type = encryption_type
        if target_origin is not None:
          self.target_origin = target_origin

    @property
    def encryption_type(self):
        """
        Gets the encryption_type of this KeyParameters.
        How the card number should be encrypted in the subsequent Tokenize Card request. Possible values are RsaOaep256 or None (if using this value the card number must be in plain text when included in the Tokenize Card request). The Tokenize Card request uses a secure connection (TLS 1.2+) regardless of what encryption type is specified.

        :return: The encryption_type of this KeyParameters.
        :rtype: str
        """
        return self._encryption_type

    @encryption_type.setter
    def encryption_type(self, encryption_type):
        """
        Sets the encryption_type of this KeyParameters.
        How the card number should be encrypted in the subsequent Tokenize Card request. Possible values are RsaOaep256 or None (if using this value the card number must be in plain text when included in the Tokenize Card request). The Tokenize Card request uses a secure connection (TLS 1.2+) regardless of what encryption type is specified.

        :param encryption_type: The encryption_type of this KeyParameters.
        :type: str
        """
        if encryption_type is None:
            raise ValueError("Invalid value for `encryption_type`, must not be `None`")

        self._encryption_type = encryption_type

    @property
    def target_origin(self):
        """
        Gets the target_origin of this KeyParameters.
        The merchant origin (e.g. https://example.com) used to integrate with Flex API. Required to comply with CORS and CSP standards.

        :return: The target_origin of this KeyParameters.
        :rtype: str
        """
        return self._target_origin

    @target_origin.setter
    def target_origin(self, target_origin):
        """
        Sets the target_origin of this KeyParameters.
        The merchant origin (e.g. https://example.com) used to integrate with Flex API. Required to comply with CORS and CSP standards.

        :param target_origin: The target_origin of this KeyParameters.
        :type: str
        """

        self._target_origin = target_origin

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, KeyParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Vasv2taxTaxInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reporting_date': 'str',
        'date_override_reason': 'str',
        'nexus': 'list[str]',
        'no_nexus': 'list[str]',
        'show_tax_per_line_item': 'str',
        'commit_indicator': 'bool',
        'refund_indicator': 'bool'
    }

    attribute_map = {
        'reporting_date': 'reportingDate',
        'date_override_reason': 'dateOverrideReason',
        'nexus': 'nexus',
        'no_nexus': 'noNexus',
        'show_tax_per_line_item': 'showTaxPerLineItem',
        'commit_indicator': 'commitIndicator',
        'refund_indicator': 'refundIndicator'
    }

    def __init__(self, reporting_date=None, date_override_reason=None, nexus=None, no_nexus=None, show_tax_per_line_item=None, commit_indicator=None, refund_indicator=None):
        """
        Vasv2taxTaxInformation - a model defined in Swagger
        """

        self._reporting_date = None
        self._date_override_reason = None
        self._nexus = None
        self._no_nexus = None
        self._show_tax_per_line_item = None
        self._commit_indicator = None
        self._refund_indicator = None

        if reporting_date is not None:
          self.reporting_date = reporting_date
        if date_override_reason is not None:
          self.date_override_reason = date_override_reason
        if nexus is not None:
          self.nexus = nexus
        if no_nexus is not None:
          self.no_nexus = no_nexus
        if show_tax_per_line_item is not None:
          self.show_tax_per_line_item = show_tax_per_line_item
        if commit_indicator is not None:
          self.commit_indicator = commit_indicator
        if refund_indicator is not None:
          self.refund_indicator = refund_indicator

    @property
    def reporting_date(self):
        """
        Gets the reporting_date of this Vasv2taxTaxInformation.
        Reporting date of transaction. Format: YYYYMMDD. Defaults to current date if not specified. Also the default tax calculation date unless a different date is specified in `orderInformation.invoiceDetails.invoiceDate`.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The reporting_date of this Vasv2taxTaxInformation.
        :rtype: str
        """
        return self._reporting_date

    @reporting_date.setter
    def reporting_date(self, reporting_date):
        """
        Sets the reporting_date of this Vasv2taxTaxInformation.
        Reporting date of transaction. Format: YYYYMMDD. Defaults to current date if not specified. Also the default tax calculation date unless a different date is specified in `orderInformation.invoiceDetails.invoiceDate`.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param reporting_date: The reporting_date of this Vasv2taxTaxInformation.
        :type: str
        """
        if reporting_date is not None and len(reporting_date) > 8:
            raise ValueError("Invalid value for `reporting_date`, length must be less than or equal to `8`")

        self._reporting_date = reporting_date

    @property
    def date_override_reason(self):
        """
        Gets the date_override_reason of this Vasv2taxTaxInformation.
        If a past or future date is specified in `orderInformation.invoiceDetails.invoiceDate`, then provide the reason for that for audit purposes. Typical reasons include: 'Return', 'Layaway', 'Imported'.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The date_override_reason of this Vasv2taxTaxInformation.
        :rtype: str
        """
        return self._date_override_reason

    @date_override_reason.setter
    def date_override_reason(self, date_override_reason):
        """
        Sets the date_override_reason of this Vasv2taxTaxInformation.
        If a past or future date is specified in `orderInformation.invoiceDetails.invoiceDate`, then provide the reason for that for audit purposes. Typical reasons include: 'Return', 'Layaway', 'Imported'.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param date_override_reason: The date_override_reason of this Vasv2taxTaxInformation.
        :type: str
        """
        if date_override_reason is not None and len(date_override_reason) > 50:
            raise ValueError("Invalid value for `date_override_reason`, length must be less than or equal to `50`")

        self._date_override_reason = date_override_reason

    @property
    def nexus(self):
        """
        Gets the nexus of this Vasv2taxTaxInformation.
        Comma-separated list of states or provinces in which merchandise is taxable. Note merchandise may be still be non-taxable or tax exempt depending on the product taxability. Indicate the type of product you are selling in the product code field for product-level taxability rules to be applied. Do not use both the `taxInformation.nexus` and `taxInformation.noNexus` fields in your request. If you do not include this field in a tax calculation service request, the tax system makes its calculations as if you have nexus in every US state or Canadian province. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  If you indicate you do not have nexus in the destination state, jurisdiction level fields are left blank in the Tax Detail Report.  Optional field for U.S. and Canadian taxes only. Either this field or `taxInformation.noNexus` is required if you do not have nexus in every state or province.  Not applicable for international and value added taxes. 

        :return: The nexus of this Vasv2taxTaxInformation.
        :rtype: list[str]
        """
        return self._nexus

    @nexus.setter
    def nexus(self, nexus):
        """
        Sets the nexus of this Vasv2taxTaxInformation.
        Comma-separated list of states or provinces in which merchandise is taxable. Note merchandise may be still be non-taxable or tax exempt depending on the product taxability. Indicate the type of product you are selling in the product code field for product-level taxability rules to be applied. Do not use both the `taxInformation.nexus` and `taxInformation.noNexus` fields in your request. If you do not include this field in a tax calculation service request, the tax system makes its calculations as if you have nexus in every US state or Canadian province. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  If you indicate you do not have nexus in the destination state, jurisdiction level fields are left blank in the Tax Detail Report.  Optional field for U.S. and Canadian taxes only. Either this field or `taxInformation.noNexus` is required if you do not have nexus in every state or province.  Not applicable for international and value added taxes. 

        :param nexus: The nexus of this Vasv2taxTaxInformation.
        :type: list[str]
        """

        self._nexus = nexus

    @property
    def no_nexus(self):
        """
        Gets the no_nexus of this Vasv2taxTaxInformation.
        Comma-separated list of states or provinces where you do not have nexus. Check with a tax advisor to determine where your business has nexus. Do not use both the `taxInformation.nexus` and `taxInformation.noNexus` fields in your request. If you do not include this field in a tax calculation service request, the tax system makes its calculations as if you have nexus in every US state or Canadian province. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  If you indicate you do not have nexus in the destination state, jurisdiction level fields are left blank in the Tax Detail Report.  Optional field for U.S. and Canadian taxes only. Either this field or `taxInformation.nexus` is required if you do not have nexus in every state or province.  Not applicable for international and value added taxes. 

        :return: The no_nexus of this Vasv2taxTaxInformation.
        :rtype: list[str]
        """
        return self._no_nexus

    @no_nexus.setter
    def no_nexus(self, no_nexus):
        """
        Sets the no_nexus of this Vasv2taxTaxInformation.
        Comma-separated list of states or provinces where you do not have nexus. Check with a tax advisor to determine where your business has nexus. Do not use both the `taxInformation.nexus` and `taxInformation.noNexus` fields in your request. If you do not include this field in a tax calculation service request, the tax system makes its calculations as if you have nexus in every US state or Canadian province. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  If you indicate you do not have nexus in the destination state, jurisdiction level fields are left blank in the Tax Detail Report.  Optional field for U.S. and Canadian taxes only. Either this field or `taxInformation.nexus` is required if you do not have nexus in every state or province.  Not applicable for international and value added taxes. 

        :param no_nexus: The no_nexus of this Vasv2taxTaxInformation.
        :type: list[str]
        """

        self._no_nexus = no_nexus

    @property
    def show_tax_per_line_item(self):
        """
        Gets the show_tax_per_line_item of this Vasv2taxTaxInformation.
        Whether or not to display tax amounts for each line item. This field can contain one of the following values: - `Yes` - Display tax amounts for each line item - `No` (default) - Do not display tax amounts for each line item  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The show_tax_per_line_item of this Vasv2taxTaxInformation.
        :rtype: str
        """
        return self._show_tax_per_line_item

    @show_tax_per_line_item.setter
    def show_tax_per_line_item(self, show_tax_per_line_item):
        """
        Sets the show_tax_per_line_item of this Vasv2taxTaxInformation.
        Whether or not to display tax amounts for each line item. This field can contain one of the following values: - `Yes` - Display tax amounts for each line item - `No` (default) - Do not display tax amounts for each line item  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param show_tax_per_line_item: The show_tax_per_line_item of this Vasv2taxTaxInformation.
        :type: str
        """

        self._show_tax_per_line_item = show_tax_per_line_item

    @property
    def commit_indicator(self):
        """
        Gets the commit_indicator of this Vasv2taxTaxInformation.
        Indicates whether this is a committed tax transaction. For a committed tax transaction, the status in the Tax Detail Report is “Committed.” For an uncommitted tax transaction, the status in the Tax Detail Report is “Uncommitted.” Possible values: - `true`: This is a committed tax transaction. - `false` (default): This is not a committed tax transaction.  A committed tax request is a tax service request that sets the status field in the Tax Detail Report to committed. The committed status indicates that the amount calculated by the tax service is included in the amount of a capture or credit.  Use a void service request to cancels a committed tax request or a committed refund tax request. The void transaction is included as a separate entry in the Tax Detail Report. The value of the status field is cancelled. The value of the link ID is the request ID of the committed tax request or refund tax request that was voided. You can use the value of the link ID to reconcile your orders.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The commit_indicator of this Vasv2taxTaxInformation.
        :rtype: bool
        """
        return self._commit_indicator

    @commit_indicator.setter
    def commit_indicator(self, commit_indicator):
        """
        Sets the commit_indicator of this Vasv2taxTaxInformation.
        Indicates whether this is a committed tax transaction. For a committed tax transaction, the status in the Tax Detail Report is “Committed.” For an uncommitted tax transaction, the status in the Tax Detail Report is “Uncommitted.” Possible values: - `true`: This is a committed tax transaction. - `false` (default): This is not a committed tax transaction.  A committed tax request is a tax service request that sets the status field in the Tax Detail Report to committed. The committed status indicates that the amount calculated by the tax service is included in the amount of a capture or credit.  Use a void service request to cancels a committed tax request or a committed refund tax request. The void transaction is included as a separate entry in the Tax Detail Report. The value of the status field is cancelled. The value of the link ID is the request ID of the committed tax request or refund tax request that was voided. You can use the value of the link ID to reconcile your orders.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param commit_indicator: The commit_indicator of this Vasv2taxTaxInformation.
        :type: bool
        """

        self._commit_indicator = commit_indicator

    @property
    def refund_indicator(self):
        """
        Gets the refund_indicator of this Vasv2taxTaxInformation.
        Indicates whether this is a refund tax transaction. For a refund tax transaction, amounts in the Tax Detail Report will be negative. Possible values: - `true`: This is a refund tax transaction. - `false` (default): This is not a refund tax transaction.  A refund tax request is a tax service request that sets the transaction type field in the Tax Detail Report to refunded and makes the reported amount negative. Tax amounts are returned as positive amounts in reply messages, but they are saved in reports as negative amounts which enables the reporting software to accurately calculate the aggregate amounts.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The refund_indicator of this Vasv2taxTaxInformation.
        :rtype: bool
        """
        return self._refund_indicator

    @refund_indicator.setter
    def refund_indicator(self, refund_indicator):
        """
        Sets the refund_indicator of this Vasv2taxTaxInformation.
        Indicates whether this is a refund tax transaction. For a refund tax transaction, amounts in the Tax Detail Report will be negative. Possible values: - `true`: This is a refund tax transaction. - `false` (default): This is not a refund tax transaction.  A refund tax request is a tax service request that sets the transaction type field in the Tax Detail Report to refunded and makes the reported amount negative. Tax amounts are returned as positive amounts in reply messages, but they are saved in reports as negative amounts which enables the reporting software to accurately calculate the aggregate amounts.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param refund_indicator: The refund_indicator of this Vasv2taxTaxInformation.
        :type: bool
        """

        self._refund_indicator = refund_indicator

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Vasv2taxTaxInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CreateSearchRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'save': 'bool',
        'name': 'str',
        'timezone': 'str',
        'query': 'str',
        'offset': 'int',
        'limit': 'int',
        'sort': 'str'
    }

    attribute_map = {
        'save': 'save',
        'name': 'name',
        'timezone': 'timezone',
        'query': 'query',
        'offset': 'offset',
        'limit': 'limit',
        'sort': 'sort'
    }

    def __init__(self, save=None, name=None, timezone=None, query=None, offset=None, limit=None, sort=None):
        """
        CreateSearchRequest - a model defined in Swagger
        """

        self._save = None
        self._name = None
        self._timezone = None
        self._query = None
        self._offset = None
        self._limit = None
        self._sort = None

        if save is not None:
          self.save = save
        if name is not None:
          self.name = name
        if timezone is not None:
          self.timezone = timezone
        if query is not None:
          self.query = query
        if offset is not None:
          self.offset = offset
        if limit is not None:
          self.limit = limit
        if sort is not None:
          self.sort = sort

    @property
    def save(self):
        """
        Gets the save of this CreateSearchRequest.
        Indicates whether or not you want to save this search request for future use. The options are:  * `true` * `false` (default value)  If set to `true`, this field returns `searchID` in the response. You can use this value to retrieve the details of the saved search. 

        :return: The save of this CreateSearchRequest.
        :rtype: bool
        """
        return self._save

    @save.setter
    def save(self, save):
        """
        Sets the save of this CreateSearchRequest.
        Indicates whether or not you want to save this search request for future use. The options are:  * `true` * `false` (default value)  If set to `true`, this field returns `searchID` in the response. You can use this value to retrieve the details of the saved search. 

        :param save: The save of this CreateSearchRequest.
        :type: bool
        """

        self._save = save

    @property
    def name(self):
        """
        Gets the name of this CreateSearchRequest.
        Name of this search. When `save` is set to `true`, this search is saved with this name. 

        :return: The name of this CreateSearchRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateSearchRequest.
        Name of this search. When `save` is set to `true`, this search is saved with this name. 

        :param name: The name of this CreateSearchRequest.
        :type: str
        """

        self._name = name

    @property
    def timezone(self):
        """
        Gets the timezone of this CreateSearchRequest.
        Merchant’s time zone in ISO standard, using the TZ database format. For example: `America/Chicago` 

        :return: The timezone of this CreateSearchRequest.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this CreateSearchRequest.
        Merchant’s time zone in ISO standard, using the TZ database format. For example: `America/Chicago` 

        :param timezone: The timezone of this CreateSearchRequest.
        :type: str
        """

        self._timezone = timezone

    @property
    def query(self):
        """
        Gets the query of this CreateSearchRequest.
        String that contains the filters and variables for which you want to search. For information about supported field-filters and operators, see the [Query Filters]( https://developer.cybersource.com/api/developer-guides/dita-txn-search-details-rest-api-dev-guide-102718/txn_search_api/creating_txn_search_request.html) section of the Transaction Search Developer Guide. 

        :return: The query of this CreateSearchRequest.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this CreateSearchRequest.
        String that contains the filters and variables for which you want to search. For information about supported field-filters and operators, see the [Query Filters]( https://developer.cybersource.com/api/developer-guides/dita-txn-search-details-rest-api-dev-guide-102718/txn_search_api/creating_txn_search_request.html) section of the Transaction Search Developer Guide. 

        :param query: The query of this CreateSearchRequest.
        :type: str
        """

        self._query = query

    @property
    def offset(self):
        """
        Gets the offset of this CreateSearchRequest.
        Controls the starting point within the collection of results, which defaults to 0. The first item in the collection is retrieved by setting a zero offset.  For example, if you have a collection of 15 items to be retrieved from a resource and you specify limit=5, you can retrieve the entire set of results in 3 successive requests by varying the offset value like this:  `offset=0` `offset=5` `offset=10`  **Note:** If an offset larger than the number of results is provided, this will result in no embedded object being returned. 

        :return: The offset of this CreateSearchRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this CreateSearchRequest.
        Controls the starting point within the collection of results, which defaults to 0. The first item in the collection is retrieved by setting a zero offset.  For example, if you have a collection of 15 items to be retrieved from a resource and you specify limit=5, you can retrieve the entire set of results in 3 successive requests by varying the offset value like this:  `offset=0` `offset=5` `offset=10`  **Note:** If an offset larger than the number of results is provided, this will result in no embedded object being returned. 

        :param offset: The offset of this CreateSearchRequest.
        :type: int
        """

        self._offset = offset

    @property
    def limit(self):
        """
        Gets the limit of this CreateSearchRequest.
        Controls the maximum number of items that may be returned for a single request. The default is 20, the maximum is 2000. 

        :return: The limit of this CreateSearchRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this CreateSearchRequest.
        Controls the maximum number of items that may be returned for a single request. The default is 20, the maximum is 2000. 

        :param limit: The limit of this CreateSearchRequest.
        :type: int
        """

        self._limit = limit

    @property
    def sort(self):
        """
        Gets the sort of this CreateSearchRequest.
        A comma separated list of the following form:  `submitTimeUtc:desc` 

        :return: The sort of this CreateSearchRequest.
        :rtype: str
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """
        Sets the sort of this CreateSearchRequest.
        A comma separated list of the following form:  `submitTimeUtc:desc` 

        :param sort: The sort of this CreateSearchRequest.
        :type: str
        """

        self._sort = sort

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CreateSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseApplicationInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'reason_code': 'str',
        'r_code': 'str',
        'r_flag': 'str',
        'applications': 'list[TssV2TransactionsGet200ResponseApplicationInformationApplications]'
    }

    attribute_map = {
        'status': 'status',
        'reason_code': 'reasonCode',
        'r_code': 'rCode',
        'r_flag': 'rFlag',
        'applications': 'applications'
    }

    def __init__(self, status=None, reason_code=None, r_code=None, r_flag=None, applications=None):
        """
        TssV2TransactionsGet200ResponseApplicationInformation - a model defined in Swagger
        """

        self._status = None
        self._reason_code = None
        self._r_code = None
        self._r_flag = None
        self._applications = None

        if status is not None:
          self.status = status
        if reason_code is not None:
          self.reason_code = reason_code
        if r_code is not None:
          self.r_code = r_code
        if r_flag is not None:
          self.r_flag = r_flag
        if applications is not None:
          self.applications = applications

    @property
    def status(self):
        """
        Gets the status of this TssV2TransactionsGet200ResponseApplicationInformation.
        The status of the submitted transaction.

        :return: The status of this TssV2TransactionsGet200ResponseApplicationInformation.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TssV2TransactionsGet200ResponseApplicationInformation.
        The status of the submitted transaction.

        :param status: The status of this TssV2TransactionsGet200ResponseApplicationInformation.
        :type: str
        """

        self._status = status

    @property
    def reason_code(self):
        """
        Gets the reason_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        Indicates the reason why a request succeeded or failed and possible action to take if a request fails.  For details, see the appendix of reason codes in the documentation for the relevant payment method. 

        :return: The reason_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        :rtype: str
        """
        return self._reason_code

    @reason_code.setter
    def reason_code(self, reason_code):
        """
        Sets the reason_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        Indicates the reason why a request succeeded or failed and possible action to take if a request fails.  For details, see the appendix of reason codes in the documentation for the relevant payment method. 

        :param reason_code: The reason_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        :type: str
        """

        self._reason_code = reason_code

    @property
    def r_code(self):
        """
        Gets the r_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        Indicates whether the service request was successful. Possible values:  - `-1`: An error occurred. - `0`: The request was declined. - `1`: The request was successful. 

        :return: The r_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        :rtype: str
        """
        return self._r_code

    @r_code.setter
    def r_code(self, r_code):
        """
        Sets the r_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        Indicates whether the service request was successful. Possible values:  - `-1`: An error occurred. - `0`: The request was declined. - `1`: The request was successful. 

        :param r_code: The r_code of this TssV2TransactionsGet200ResponseApplicationInformation.
        :type: str
        """

        self._r_code = r_code

    @property
    def r_flag(self):
        """
        Gets the r_flag of this TssV2TransactionsGet200ResponseApplicationInformation.
        One-word description of the result of the application. 

        :return: The r_flag of this TssV2TransactionsGet200ResponseApplicationInformation.
        :rtype: str
        """
        return self._r_flag

    @r_flag.setter
    def r_flag(self, r_flag):
        """
        Sets the r_flag of this TssV2TransactionsGet200ResponseApplicationInformation.
        One-word description of the result of the application. 

        :param r_flag: The r_flag of this TssV2TransactionsGet200ResponseApplicationInformation.
        :type: str
        """

        self._r_flag = r_flag

    @property
    def applications(self):
        """
        Gets the applications of this TssV2TransactionsGet200ResponseApplicationInformation.

        :return: The applications of this TssV2TransactionsGet200ResponseApplicationInformation.
        :rtype: list[TssV2TransactionsGet200ResponseApplicationInformationApplications]
        """
        return self._applications

    @applications.setter
    def applications(self, applications):
        """
        Sets the applications of this TssV2TransactionsGet200ResponseApplicationInformation.

        :param applications: The applications of this TssV2TransactionsGet200ResponseApplicationInformation.
        :type: list[TssV2TransactionsGet200ResponseApplicationInformationApplications]
        """

        self._applications = applications

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseApplicationInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PayoutsPost201ResponseProcessorInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'approval_code': 'str',
        'response_code': 'str',
        'transaction_id': 'str',
        'system_trace_audit_number': 'str',
        'response_code_source': 'str'
    }

    attribute_map = {
        'approval_code': 'approvalCode',
        'response_code': 'responseCode',
        'transaction_id': 'transactionId',
        'system_trace_audit_number': 'systemTraceAuditNumber',
        'response_code_source': 'responseCodeSource'
    }

    def __init__(self, approval_code=None, response_code=None, transaction_id=None, system_trace_audit_number=None, response_code_source=None):
        """
        PtsV2PayoutsPost201ResponseProcessorInformation - a model defined in Swagger
        """

        self._approval_code = None
        self._response_code = None
        self._transaction_id = None
        self._system_trace_audit_number = None
        self._response_code_source = None

        if approval_code is not None:
          self.approval_code = approval_code
        if response_code is not None:
          self.response_code = response_code
        if transaction_id is not None:
          self.transaction_id = transaction_id
        if system_trace_audit_number is not None:
          self.system_trace_audit_number = system_trace_audit_number
        if response_code_source is not None:
          self.response_code_source = response_code_source

    @property
    def approval_code(self):
        """
        Gets the approval_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Issuer-generated approval code for the transaction.

        :return: The approval_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._approval_code

    @approval_code.setter
    def approval_code(self, approval_code):
        """
        Sets the approval_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Issuer-generated approval code for the transaction.

        :param approval_code: The approval_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :type: str
        """
        if approval_code is not None and len(approval_code) > 6:
            raise ValueError("Invalid value for `approval_code`, length must be less than or equal to `6`")

        self._approval_code = approval_code

    @property
    def response_code(self):
        """
        Gets the response_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Transaction status from the processor.

        :return: The response_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._response_code

    @response_code.setter
    def response_code(self, response_code):
        """
        Sets the response_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Transaction status from the processor.

        :param response_code: The response_code of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :type: str
        """
        if response_code is not None and len(response_code) > 10:
            raise ValueError("Invalid value for `response_code`, length must be less than or equal to `10`")

        self._response_code = response_code

    @property
    def transaction_id(self):
        """
        Gets the transaction_id of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor. 

        :return: The transaction_id of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """
        Sets the transaction_id of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor. 

        :param transaction_id: The transaction_id of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :type: str
        """
        if transaction_id is not None and len(transaction_id) > 15:
            raise ValueError("Invalid value for `transaction_id`, length must be less than or equal to `15`")

        self._transaction_id = transaction_id

    @property
    def system_trace_audit_number(self):
        """
        Gets the system_trace_audit_number of this PtsV2PayoutsPost201ResponseProcessorInformation.
        This field is returned only for **American Express Direct** and **CyberSource through VisaNet**. Returned by authorization and incremental authorization services.  #### American Express Direct  System trace audit number (STAN). This value identifies the transaction and is useful when investigating a chargeback dispute.  #### CyberSource through VisaNet  System trace number that must be printed on the customer’s receipt. 

        :return: The system_trace_audit_number of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._system_trace_audit_number

    @system_trace_audit_number.setter
    def system_trace_audit_number(self, system_trace_audit_number):
        """
        Sets the system_trace_audit_number of this PtsV2PayoutsPost201ResponseProcessorInformation.
        This field is returned only for **American Express Direct** and **CyberSource through VisaNet**. Returned by authorization and incremental authorization services.  #### American Express Direct  System trace audit number (STAN). This value identifies the transaction and is useful when investigating a chargeback dispute.  #### CyberSource through VisaNet  System trace number that must be printed on the customer’s receipt. 

        :param system_trace_audit_number: The system_trace_audit_number of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :type: str
        """
        if system_trace_audit_number is not None and len(system_trace_audit_number) > 6:
            raise ValueError("Invalid value for `system_trace_audit_number`, length must be less than or equal to `6`")

        self._system_trace_audit_number = system_trace_audit_number

    @property
    def response_code_source(self):
        """
        Gets the response_code_source of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Used by Visa only and contains the response source/reason code that identifies the source of the response decision. 

        :return: The response_code_source of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._response_code_source

    @response_code_source.setter
    def response_code_source(self, response_code_source):
        """
        Sets the response_code_source of this PtsV2PayoutsPost201ResponseProcessorInformation.
        Used by Visa only and contains the response source/reason code that identifies the source of the response decision. 

        :param response_code_source: The response_code_source of this PtsV2PayoutsPost201ResponseProcessorInformation.
        :type: str
        """
        if response_code_source is not None and len(response_code_source) > 1:
            raise ValueError("Invalid value for `response_code_source`, length must be less than or equal to `1`")

        self._response_code_source = response_code_source

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PayoutsPost201ResponseProcessorInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidcapturesPointOfSaleInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'emv': 'Ptsv2paymentsidcapturesPointOfSaleInformationEmv',
        'amex_capn_data': 'str'
    }

    attribute_map = {
        'emv': 'emv',
        'amex_capn_data': 'amexCapnData'
    }

    def __init__(self, emv=None, amex_capn_data=None):
        """
        Ptsv2paymentsidcapturesPointOfSaleInformation - a model defined in Swagger
        """

        self._emv = None
        self._amex_capn_data = None

        if emv is not None:
          self.emv = emv
        if amex_capn_data is not None:
          self.amex_capn_data = amex_capn_data

    @property
    def emv(self):
        """
        Gets the emv of this Ptsv2paymentsidcapturesPointOfSaleInformation.

        :return: The emv of this Ptsv2paymentsidcapturesPointOfSaleInformation.
        :rtype: Ptsv2paymentsidcapturesPointOfSaleInformationEmv
        """
        return self._emv

    @emv.setter
    def emv(self, emv):
        """
        Sets the emv of this Ptsv2paymentsidcapturesPointOfSaleInformation.

        :param emv: The emv of this Ptsv2paymentsidcapturesPointOfSaleInformation.
        :type: Ptsv2paymentsidcapturesPointOfSaleInformationEmv
        """

        self._emv = emv

    @property
    def amex_capn_data(self):
        """
        Gets the amex_capn_data of this Ptsv2paymentsidcapturesPointOfSaleInformation.
        Point-of-sale details for the transaction. This value is returned only for **American Express Direct**. CyberSource generates this value, which consists of a series of codes that identify terminal capability, security data, and specific conditions present at the time the transaction occurred. To comply with the CAPN requirements, this value must be included in all subsequent follow-on requests, such as captures and follow-on credits.  When you perform authorizations, captures, and credits through CyberSource, CyberSource passes this value from the authorization service to the subsequent services for you. However, when you perform authorizations through CyberSource and perform subsequent services through other financial institutions, you must ensure that your requests for captures and credits include this value.  For details, see `auth_pos_data` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The amex_capn_data of this Ptsv2paymentsidcapturesPointOfSaleInformation.
        :rtype: str
        """
        return self._amex_capn_data

    @amex_capn_data.setter
    def amex_capn_data(self, amex_capn_data):
        """
        Sets the amex_capn_data of this Ptsv2paymentsidcapturesPointOfSaleInformation.
        Point-of-sale details for the transaction. This value is returned only for **American Express Direct**. CyberSource generates this value, which consists of a series of codes that identify terminal capability, security data, and specific conditions present at the time the transaction occurred. To comply with the CAPN requirements, this value must be included in all subsequent follow-on requests, such as captures and follow-on credits.  When you perform authorizations, captures, and credits through CyberSource, CyberSource passes this value from the authorization service to the subsequent services for you. However, when you perform authorizations through CyberSource and perform subsequent services through other financial institutions, you must ensure that your requests for captures and credits include this value.  For details, see `auth_pos_data` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param amex_capn_data: The amex_capn_data of this Ptsv2paymentsidcapturesPointOfSaleInformation.
        :type: str
        """
        if amex_capn_data is not None and len(amex_capn_data) > 15:
            raise ValueError("Invalid value for `amex_capn_data`, length must be less than or equal to `15`")

        self._amex_capn_data = amex_capn_data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidcapturesPointOfSaleInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PatchCustomerRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'Tmsv2customersLinks',
        'id': 'str',
        'object_information': 'Tmsv2customersObjectInformation',
        'buyer_information': 'Tmsv2customersBuyerInformation',
        'client_reference_information': 'Tmsv2customersClientReferenceInformation',
        'merchant_defined_information': 'list[Tmsv2customersMerchantDefinedInformation]',
        'default_payment_instrument': 'Tmsv2customersDefaultPaymentInstrument',
        'default_shipping_address': 'Tmsv2customersDefaultShippingAddress',
        'metadata': 'Tmsv2customersMetadata',
        'embedded': 'Tmsv2customersEmbedded'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'object_information': 'objectInformation',
        'buyer_information': 'buyerInformation',
        'client_reference_information': 'clientReferenceInformation',
        'merchant_defined_information': 'merchantDefinedInformation',
        'default_payment_instrument': 'defaultPaymentInstrument',
        'default_shipping_address': 'defaultShippingAddress',
        'metadata': 'metadata',
        'embedded': '_embedded'
    }

    def __init__(self, links=None, id=None, object_information=None, buyer_information=None, client_reference_information=None, merchant_defined_information=None, default_payment_instrument=None, default_shipping_address=None, metadata=None, embedded=None):
        """
        PatchCustomerRequest - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._object_information = None
        self._buyer_information = None
        self._client_reference_information = None
        self._merchant_defined_information = None
        self._default_payment_instrument = None
        self._default_shipping_address = None
        self._metadata = None
        self._embedded = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if object_information is not None:
          self.object_information = object_information
        if buyer_information is not None:
          self.buyer_information = buyer_information
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if merchant_defined_information is not None:
          self.merchant_defined_information = merchant_defined_information
        if default_payment_instrument is not None:
          self.default_payment_instrument = default_payment_instrument
        if default_shipping_address is not None:
          self.default_shipping_address = default_shipping_address
        if metadata is not None:
          self.metadata = metadata
        if embedded is not None:
          self.embedded = embedded

    @property
    def links(self):
        """
        Gets the links of this PatchCustomerRequest.

        :return: The links of this PatchCustomerRequest.
        :rtype: Tmsv2customersLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this PatchCustomerRequest.

        :param links: The links of this PatchCustomerRequest.
        :type: Tmsv2customersLinks
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this PatchCustomerRequest.
        The id of the Customer Token.

        :return: The id of this PatchCustomerRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PatchCustomerRequest.
        The id of the Customer Token.

        :param id: The id of this PatchCustomerRequest.
        :type: str
        """
        if id is not None and len(id) > 32:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `32`")
        if id is not None and len(id) < 1:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `1`")

        self._id = id

    @property
    def object_information(self):
        """
        Gets the object_information of this PatchCustomerRequest.

        :return: The object_information of this PatchCustomerRequest.
        :rtype: Tmsv2customersObjectInformation
        """
        return self._object_information

    @object_information.setter
    def object_information(self, object_information):
        """
        Sets the object_information of this PatchCustomerRequest.

        :param object_information: The object_information of this PatchCustomerRequest.
        :type: Tmsv2customersObjectInformation
        """

        self._object_information = object_information

    @property
    def buyer_information(self):
        """
        Gets the buyer_information of this PatchCustomerRequest.

        :return: The buyer_information of this PatchCustomerRequest.
        :rtype: Tmsv2customersBuyerInformation
        """
        return self._buyer_information

    @buyer_information.setter
    def buyer_information(self, buyer_information):
        """
        Sets the buyer_information of this PatchCustomerRequest.

        :param buyer_information: The buyer_information of this PatchCustomerRequest.
        :type: Tmsv2customersBuyerInformation
        """

        self._buyer_information = buyer_information

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this PatchCustomerRequest.

        :return: The client_reference_information of this PatchCustomerRequest.
        :rtype: Tmsv2customersClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this PatchCustomerRequest.

        :param client_reference_information: The client_reference_information of this PatchCustomerRequest.
        :type: Tmsv2customersClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def merchant_defined_information(self):
        """
        Gets the merchant_defined_information of this PatchCustomerRequest.
        Object containing the custom data that the merchant defines. 

        :return: The merchant_defined_information of this PatchCustomerRequest.
        :rtype: list[Tmsv2customersMerchantDefinedInformation]
        """
        return self._merchant_defined_information

    @merchant_defined_information.setter
    def merchant_defined_information(self, merchant_defined_information):
        """
        Sets the merchant_defined_information of this PatchCustomerRequest.
        Object containing the custom data that the merchant defines. 

        :param merchant_defined_information: The merchant_defined_information of this PatchCustomerRequest.
        :type: list[Tmsv2customersMerchantDefinedInformation]
        """

        self._merchant_defined_information = merchant_defined_information

    @property
    def default_payment_instrument(self):
        """
        Gets the default_payment_instrument of this PatchCustomerRequest.

        :return: The default_payment_instrument of this PatchCustomerRequest.
        :rtype: Tmsv2customersDefaultPaymentInstrument
        """
        return self._default_payment_instrument

    @default_payment_instrument.setter
    def default_payment_instrument(self, default_payment_instrument):
        """
        Sets the default_payment_instrument of this PatchCustomerRequest.

        :param default_payment_instrument: The default_payment_instrument of this PatchCustomerRequest.
        :type: Tmsv2customersDefaultPaymentInstrument
        """

        self._default_payment_instrument = default_payment_instrument

    @property
    def default_shipping_address(self):
        """
        Gets the default_shipping_address of this PatchCustomerRequest.

        :return: The default_shipping_address of this PatchCustomerRequest.
        :rtype: Tmsv2customersDefaultShippingAddress
        """
        return self._default_shipping_address

    @default_shipping_address.setter
    def default_shipping_address(self, default_shipping_address):
        """
        Sets the default_shipping_address of this PatchCustomerRequest.

        :param default_shipping_address: The default_shipping_address of this PatchCustomerRequest.
        :type: Tmsv2customersDefaultShippingAddress
        """

        self._default_shipping_address = default_shipping_address

    @property
    def metadata(self):
        """
        Gets the metadata of this PatchCustomerRequest.

        :return: The metadata of this PatchCustomerRequest.
        :rtype: Tmsv2customersMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this PatchCustomerRequest.

        :param metadata: The metadata of this PatchCustomerRequest.
        :type: Tmsv2customersMetadata
        """

        self._metadata = metadata

    @property
    def embedded(self):
        """
        Gets the embedded of this PatchCustomerRequest.

        :return: The embedded of this PatchCustomerRequest.
        :rtype: Tmsv2customersEmbedded
        """
        return self._embedded

    @embedded.setter
    def embedded(self, embedded):
        """
        Sets the embedded of this PatchCustomerRequest.

        :param embedded: The embedded of this PatchCustomerRequest.
        :type: Tmsv2customersEmbedded
        """

        self._embedded = embedded

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PatchCustomerRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
